@@ -6,9 +6,9 @@ from trava.fit_predictor import FitPredictor, FitPredictorSteps
 from trava.split.result import SplitResult
 
 
-@pytest.fixture(scope='class')
+@pytest.fixture(scope="class")
 def model_id():
-    return 'test_model_id'
+    return "test_model_id"
 
 
 @pytest.fixture()
@@ -21,7 +21,7 @@ def raw_model(mocker, model_id):
 @pytest.fixture
 def X_y_train(mocker):
     X_train = mocker.MagicMock()
-    X_train['f1'] = [1, 2, 3]
+    X_train["f1"] = [1, 2, 3]
     y_train = [0, 0, 0]
 
     return X_train, y_train
@@ -30,7 +30,7 @@ def X_y_train(mocker):
 @pytest.fixture
 def X_y_test(mocker):
     X_test = mocker.MagicMock()
-    X_test['f1'] = [4, 5, 6]
+    X_test["f1"] = [4, 5, 6]
     y_test = [1, 1, 1]
 
     return X_test, y_test
@@ -41,10 +41,7 @@ def split_result(X_y_train, X_y_test):
     X_train, y_train = X_y_train
     X_test, y_test = X_y_test
 
-    return SplitResult(X_train=X_train,
-                       y_train=y_train,
-                       X_test=X_test,
-                       y_test=y_test)
+    return SplitResult(X_train=X_train, y_train=y_train, X_test=X_test, y_test=y_test)
 
 
 @pytest.mark.parametrize("n_steps", [1, 3])
@@ -72,7 +69,7 @@ def test_model_update_steps(mocker, n_steps, raw_model):
 
 def test_models_configs(mocker, raw_model, model_id):
     fp = FitPredictor()
-    models_configs_func = mocker.patch.object(fp, '_models_configs')
+    models_configs_func = mocker.patch.object(fp, "_models_configs")
     models_configs = mocker.MagicMock()
     models_configs_func.return_value = models_configs
 
@@ -88,8 +85,8 @@ def test_models_configs(mocker, raw_model, model_id):
 
 @pytest.mark.parametrize("n_steps", [1, 3])
 def test_config_update_steps(mocker, n_steps, split_result, raw_model):
-    fit_params = {'c': 2, 'd': 3}
-    predict_params = {'_': 4, '+': 5}
+    fit_params = {"c": 2, "d": 3}
+    predict_params = {"_": 4, "+": 5}
 
     config = mocker.Mock()
     config.raw_split_data = split_result
@@ -108,7 +105,7 @@ def test_config_update_steps(mocker, n_steps, split_result, raw_model):
     fp_steps = FitPredictorSteps(config_steps=steps)
     fp = FitPredictor(steps=fp_steps)
 
-    models_configs_func = mocker.patch.object(fp, '_models_configs')
+    models_configs_func = mocker.patch.object(fp, "_models_configs")
     models_configs_func.return_value = [(mocker.Mock(), config)]
 
     tracker = mocker.Mock()
@@ -116,20 +113,18 @@ def test_config_update_steps(mocker, n_steps, split_result, raw_model):
 
     for step in steps:
         step.fit_split_data.assert_called_with(raw_split_data=split_result, config=config, tracker=tracker)
-        step.fit_params.assert_called_with(fit_params=fit_params,
-                                           fit_split_data=split_result,
-                                           config=config,
-                                           tracker=tracker)
-        step.predict_params.assert_called_with(predict_params=predict_params,
-                                               fit_split_data=split_result,
-                                               config=config,
-                                               tracker=tracker)
+        step.fit_params.assert_called_with(
+            fit_params=fit_params, fit_split_data=split_result, config=config, tracker=tracker
+        )
+        step.predict_params.assert_called_with(
+            predict_params=predict_params, fit_split_data=split_result, config=config, tracker=tracker
+        )
 
 
 @pytest.mark.parametrize("n_steps", [1, 3])
 def test_final_steps(mocker, split_result, raw_model, n_steps):
-    fit_params = {'c': 2, 'd': 3}
-    predict_params = {'_': 4, '+': 5}
+    fit_params = {"c": 2, "d": 3}
+    predict_params = {"_": 4, "+": 5}
 
     config = mocker.Mock()
     config.raw_split_data = split_result
@@ -148,7 +143,7 @@ def test_final_steps(mocker, split_result, raw_model, n_steps):
     fp_steps = FitPredictorSteps(final_steps=steps)
     fp = FitPredictor(steps=fp_steps)
 
-    models_configs_func = mocker.patch.object(fp, '_models_configs')
+    models_configs_func = mocker.patch.object(fp, "_models_configs")
     trava_model = mocker.Mock()
     models_configs_func.return_value = [(trava_model, config)]
 
@@ -160,15 +155,9 @@ def test_final_steps(mocker, split_result, raw_model, n_steps):
 
 
 @pytest.mark.parametrize("n_models", [1, 3])
-@pytest.mark.parametrize("has_description", [True, False], ids=['has_descr', 'no_descr'])
-@pytest.mark.parametrize("serializer", [TestSerializer(), None], ids=['serial', 'no_serial'])
-def test_tracking(mocker,
-                  model_id,
-                  split_result,
-                  raw_model,
-                  n_models,
-                  has_description,
-                  serializer):
+@pytest.mark.parametrize("has_description", [True, False], ids=["has_descr", "no_descr"])
+@pytest.mark.parametrize("serializer", [TestSerializer(), None], ids=["serial", "no_serial"])
+def test_tracking(mocker, model_id, split_result, raw_model, n_models, has_description, serializer):
     config = mocker.Mock()
     config.model_id = model_id
     config.raw_split_data = split_result
@@ -176,7 +165,7 @@ def test_tracking(mocker,
     config.raw_model = raw_model
     model_init_params = mocker.Mock()
 
-    description = 'descr'
+    description = "descr"
     if has_description:
         config.description = description
     else:
@@ -194,13 +183,13 @@ def test_tracking(mocker,
     for idx in range(n_models):
         nested_model = mocker.Mock()
         nested_model.raw_model = raw_model
-        nested_model_id = model_id + '_' + str(idx)
+        nested_model_id = model_id + "_" + str(idx)
         nested_model.model_id = nested_model_id
         model_config = copy(config)
         model_config.model_id = nested_model_id
         models_configs.append((nested_model, model_config))
 
-    models_configs_func = mocker.patch.object(fp, '_models_configs')
+    models_configs_func = mocker.patch.object(fp, "_models_configs")
     models_configs_func.return_value = models_configs
 
     tracker = mocker.Mock()
@@ -210,25 +199,29 @@ def test_tracking(mocker,
 
     is_multiple_models = n_models > 1
     if is_multiple_models:
-        expected_calls += _start_tracking_check_get_calls(mocker=mocker,
-                                                          model_id=model_id,
-                                                          raw_model=raw_model,
-                                                          tracker=tracker,
-                                                          description=description,
-                                                          model_init_params=model_init_params,
-                                                          has_description=has_description,
-                                                          nested=False)
+        expected_calls += _start_tracking_check_get_calls(
+            mocker=mocker,
+            model_id=model_id,
+            raw_model=raw_model,
+            tracker=tracker,
+            description=description,
+            model_init_params=model_init_params,
+            has_description=has_description,
+            nested=False,
+        )
 
     models = [model_config[0] for model_config in models_configs]
     for idx, model in enumerate(models):
-        expected_calls += _start_tracking_check_get_calls(mocker=mocker,
-                                                          model_id=model.model_id,
-                                                          raw_model=raw_model,
-                                                          tracker=tracker,
-                                                          description=description,
-                                                          model_init_params=model_init_params,
-                                                          has_description=has_description,
-                                                          nested=is_multiple_models)
+        expected_calls += _start_tracking_check_get_calls(
+            mocker=mocker,
+            model_id=model.model_id,
+            raw_model=raw_model,
+            tracker=tracker,
+            description=description,
+            model_init_params=model_init_params,
+            has_description=has_description,
+            nested=is_multiple_models,
+        )
 
         expected_calls += [
             mocker.call.track_fit_params(model_id=model.model_id, params=fit_params),
@@ -236,46 +229,39 @@ def test_tracking(mocker,
         ]
 
         model_results_kwargs = tracker.track_model_results.call_args_list[idx][1]
-        model_results = model_results_kwargs['model_results']
+        model_results = model_results_kwargs["model_results"]
         assert model_results.model_id == model.model_id
 
-        expected_calls += [
-            mocker.call.track_model_results(model_results=model_results)
-        ]
+        expected_calls += [mocker.call.track_model_results(model_results=model_results)]
 
         if serializer:
             expected_calls += [
                 mocker.call.track_model_artifact(model_id=model.model_id, model=raw_model, serializer=serializer)
             ]
 
-        expected_calls += [
-            mocker.call.end_tracking(model_id=model.model_id)
-        ]
+        expected_calls += [mocker.call.end_tracking(model_id=model.model_id)]
 
     if is_multiple_models:
         model_results_kwargs = tracker.track_model_results.call_args_list[n_models][1]
-        model_results = model_results_kwargs['model_results']
+        model_results = model_results_kwargs["model_results"]
         assert model_results.model_id == model_id
 
         expected_calls += [
             mocker.call.track_model_results(model_results=model_results),
-            mocker.call.end_tracking(model_id=model_id)
+            mocker.call.end_tracking(model_id=model_id),
         ]
 
     tracker.assert_has_calls(expected_calls)
 
 
-def _start_tracking_check_get_calls(mocker,
-                                    model_id,
-                                    raw_model,
-                                    tracker,
-                                    description,
-                                    model_init_params,
-                                    has_description: bool,
-                                    nested: bool) -> list:
-    expected_calls = [mocker.call.start_tracking(model_id=model_id, nested=nested),
-                      mocker.call.track_model_init_params(model_id=model_id, params=model_init_params),
-                      mocker.call.track_model_info(model_id=model_id, model=raw_model)]
+def _start_tracking_check_get_calls(
+    mocker, model_id, raw_model, tracker, description, model_init_params, has_description: bool, nested: bool
+) -> list:
+    expected_calls = [
+        mocker.call.start_tracking(model_id=model_id, nested=nested),
+        mocker.call.track_model_init_params(model_id=model_id, params=model_init_params),
+        mocker.call.track_model_info(model_id=model_id, model=raw_model),
+    ]
 
     if has_description:
         expected_calls.append(mocker.call.track_model_description(model_id=model_id, description=description))
@@ -300,11 +286,7 @@ def test_has_any_log_calls(mocker, split_result, raw_model):
 
 
 @pytest.mark.parametrize("n_models", [1, 3])
-def test_fit_predict(mocker,
-                     model_id,
-                     split_result,
-                     raw_model,
-                     n_models):
+def test_fit_predict(mocker, model_id, split_result, raw_model, n_models):
     config = mocker.Mock()
     config.model_id = model_id
     config.raw_split_data = split_result
@@ -319,16 +301,16 @@ def test_fit_predict(mocker,
     scorers_providers = mocker.MagicMock()
     config.scorers_providers = scorers_providers
     fp = FitPredictor()
-    fit_mock = mocker.patch.object(fp, '_fit')
+    fit_mock = mocker.patch.object(fp, "_fit")
     fit_mock.return_value = None
-    predict_mock = mocker.patch.object(fp, '_predict')
+    predict_mock = mocker.patch.object(fp, "_predict")
     predict_mock.return_value = None
 
     models_configs = []
     for idx in range(n_models):
         nested_model = mocker.Mock()
         nested_model.raw_model = raw_model
-        nested_model_id = model_id + '_' + str(idx)
+        nested_model_id = model_id + "_" + str(idx)
         nested_model.model_id = nested_model_id
 
         model_config = copy(config)
@@ -336,7 +318,7 @@ def test_fit_predict(mocker,
         model_config.model_id = nested_model_id
         models_configs.append((nested_model, model_config))
 
-    models_configs_func = mocker.patch.object(fp, '_models_configs')
+    models_configs_func = mocker.patch.object(fp, "_models_configs")
     models_configs_func.return_value = models_configs
 
     tracker = mocker.Mock()
@@ -346,35 +328,33 @@ def test_fit_predict(mocker,
     if is_multiple_models:
         for idx, (model, config) in enumerate(models_configs):
             fit_call_args = fit_mock.call_args_list[idx][1]
-            assert fit_call_args['trava_model'] == model
-            assert fit_call_args['X'] == config.raw_split_data.X_train
-            assert fit_call_args['y'] == config.raw_split_data.y_train
-            assert fit_call_args['fit_params'] == fit_params
-            assert fit_call_args['predict_params'] == predict_params
+            assert fit_call_args["trava_model"] == model
+            assert fit_call_args["X"] == config.raw_split_data.X_train
+            assert fit_call_args["y"] == config.raw_split_data.y_train
+            assert fit_call_args["fit_params"] == fit_params
+            assert fit_call_args["predict_params"] == predict_params
 
             predict_call_args = predict_mock.call_args_list[idx][1]
 
-            assert predict_call_args['trava_model'] == model
-            assert predict_call_args['X'] == config.raw_split_data.X_test
-            assert predict_call_args['y'] == config.raw_split_data.y_test
+            assert predict_call_args["trava_model"] == model
+            assert predict_call_args["X"] == config.raw_split_data.X_test
+            assert predict_call_args["y"] == config.raw_split_data.y_test
     else:
-        fit_mock.assert_called_once_with(trava_model=models_configs[0][0],
-                                         X=split_result.X_train,
-                                         y=split_result.y_train,
-                                         fit_params=fit_params,
-                                         predict_params=predict_params)
+        fit_mock.assert_called_once_with(
+            trava_model=models_configs[0][0],
+            X=split_result.X_train,
+            y=split_result.y_train,
+            fit_params=fit_params,
+            predict_params=predict_params,
+        )
 
-        predict_mock.assert_called_once_with(trava_model=models_configs[0][0],
-                                             X=split_result.X_test,
-                                             y=split_result.y_test)
+        predict_mock.assert_called_once_with(
+            trava_model=models_configs[0][0], X=split_result.X_test, y=split_result.y_test
+        )
 
 
 @pytest.mark.parametrize("n_models", [1, 3])
-def test_return_evaluators(mocker,
-                           model_id,
-                           split_result,
-                           raw_model,
-                           n_models):
+def test_return_evaluators(mocker, model_id, split_result, raw_model, n_models):
     config = mocker.Mock()
     config.model_id = model_id
     config.raw_split_data = split_result
@@ -393,13 +373,13 @@ def test_return_evaluators(mocker,
     for idx in range(n_models):
         nested_model = mocker.Mock()
         nested_model.raw_model = raw_model
-        nested_model_id = model_id + '_' + str(idx)
+        nested_model_id = model_id + "_" + str(idx)
         nested_model.model_id = nested_model_id
         model_config = copy(config)
         model_config.model_id = nested_model_id
         models_configs.append((nested_model, model_config))
 
-    models_configs_func = mocker.patch.object(fp, '_models_configs')
+    models_configs_func = mocker.patch.object(fp, "_models_configs")
     models_configs_func.return_value = models_configs
 
     tracker = mocker.Mock()
@@ -427,11 +407,7 @@ def test_return_evaluators(mocker,
 
 
 @pytest.mark.parametrize("n_models", [1, 3])
-def test_evaluators_get_called(mocker,
-                               model_id,
-                               split_result,
-                               raw_model,
-                               n_models):
+def test_evaluators_get_called(mocker, model_id, split_result, raw_model, n_models):
     config = mocker.Mock()
     config.model_id = model_id
     config.raw_split_data = split_result
@@ -451,16 +427,16 @@ def test_evaluators_get_called(mocker,
     for idx in range(n_models):
         nested_model = mocker.Mock()
         nested_model.raw_model = raw_model
-        nested_model_id = model_id + '_' + str(idx)
+        nested_model_id = model_id + "_" + str(idx)
         nested_model.model_id = nested_model_id
         model_config = copy(config)
         model_config.model_id = nested_model_id
         models_configs.append((nested_model, model_config))
 
-    models_configs_func = mocker.patch.object(fp, '_models_configs')
+    models_configs_func = mocker.patch.object(fp, "_models_configs")
     models_configs_func.return_value = models_configs
 
-    evaluator_func = mocker.patch.object(fp, '_evaluator')
+    evaluator_func = mocker.patch.object(fp, "_evaluator")
     evaluator_func.return_value = mocker.Mock()
 
     evaluators = fp.fit_predict(config=config, tracker=mocker.Mock())
@@ -473,9 +449,9 @@ def test_evaluators_get_called(mocker,
             evaluator = evaluators[idx]
 
             eval_func_args = evaluator_func.call_args_list[idx][1]
-            assert eval_func_args['model_config'] == config
-            assert eval_func_args['split_result'] == config.raw_split_data
-            assert eval_func_args['model'] == model
+            assert eval_func_args["model_config"] == config
+            assert eval_func_args["split_result"] == config.raw_split_data
+            assert eval_func_args["model"] == model
 
             evaluator.evaluate.assert_called_with(scorers_providers=scorers_providers)
     else:
@@ -483,7 +459,5 @@ def test_evaluators_get_called(mocker,
         config = models_configs[0][1]
         evaluator = evaluators[0]
 
-        evaluator_func.assert_called_with(model_config=config,
-                                          split_result=split_result,
-                                          model=model)
+        evaluator_func.assert_called_with(model_config=config, split_result=split_result, model=model)
         evaluator.evaluate.assert_called_with(scorers_providers=scorers_providers)
