@@ -18,19 +18,22 @@ class TravaSV(_TravaBase):
     """
     Made for working with supervised problems.
     """
-    def fit_predict(self,
-                    model_id: str,
-                    model_type: Type,
-                    description: Optional[str] = None,
-                    model_init_params: Optional[dict] = None,
-                    raw_split_data: Optional[SplitResult] = None,
-                    fit_predictor: FitPredictor = None,
-                    fit_params: dict = None,
-                    predict_params: dict = None,
-                    only_calculate_metrics: bool = False,
-                    keep_models_in_memory: bool = True,
-                    keep_data_in_memory: bool = True,
-                    serializer: Optional[ModelSerializer] = None):
+
+    def fit_predict(
+        self,
+        model_id: str,
+        model_type: Type,
+        description: Optional[str] = None,
+        model_init_params: Optional[dict] = None,
+        raw_split_data: Optional[SplitResult] = None,
+        fit_predictor: FitPredictor = None,
+        fit_params: dict = None,
+        predict_params: dict = None,
+        only_calculate_metrics: bool = False,
+        keep_models_in_memory: bool = True,
+        keep_data_in_memory: bool = True,
+        serializer: Optional[ModelSerializer] = None,
+    ):
         """
         Calls model's fit and predict with the data provided, calculates metrics and stores them.
         model_type and model_init_params were separated for the sake of easy parameters tracking.
@@ -75,28 +78,29 @@ class TravaSV(_TravaBase):
         model_init_params = model_init_params or {}
         fit_predictor = fit_predictor or FitPredictor(logger=self._logger)
 
-        raw_model, model_init_params = self._create_raw_model(model_type=model_type,
-                                                              model_init_params=model_init_params)
+        raw_model, model_init_params = self._create_raw_model(
+            model_type=model_type, model_init_params=model_init_params
+        )
 
-        evaluators = self._fit_predict(raw_model=raw_model,
-                                       model_id=model_id,
-                                       model_init_params=model_init_params,
-                                       fit_predictor=fit_predictor,
-                                       fit_params=fit_params,
-                                       predict_params=predict_params,
-                                       serializer=serializer,
-                                       split_result=raw_split_data,
-                                       description=description)
+        evaluators = self._fit_predict(
+            raw_model=raw_model,
+            model_id=model_id,
+            model_init_params=model_init_params,
+            fit_predictor=fit_predictor,
+            fit_params=fit_params,
+            predict_params=predict_params,
+            serializer=serializer,
+            split_result=raw_split_data,
+            description=description,
+        )
         result = None
 
         if only_calculate_metrics:
-            self._prepare_model_results(evaluators=evaluators,
-                                        save=True,
-                                        main_model_id=model_id)
+            self._prepare_model_results(evaluators=evaluators, save=True, main_model_id=model_id)
         else:
-            result = self._results_for_evaluators(evaluators=evaluators,
-                                                  save_model_results=True,
-                                                  main_model_id=model_id)
+            result = self._results_for_evaluators(
+                evaluators=evaluators, save_model_results=True, main_model_id=model_id
+            )
 
         if not keep_models_in_memory:
             [evaluator.trava_model.unload_model() for evaluator in evaluators]
@@ -105,10 +109,7 @@ class TravaSV(_TravaBase):
             [evaluator.unload_data() for evaluator in evaluators]
         return result
 
-    def evaluate(self,
-                 model_id: str,
-                 results_handlers: List[ResultsHandler],
-                 save_results: bool) -> list:
+    def evaluate(self, model_id: str, results_handlers: List[ResultsHandler], save_results: bool) -> list:
         """
         Make possible to evaluate an existing model using new results handlers.
         Made in case you forgot to pass all the handlers in init
@@ -136,22 +137,22 @@ class TravaSV(_TravaBase):
                 evaluator.evaluate(scorers_providers=results_handlers)
 
             # copy of evaluator just to get the results
-            temp_evaluator = Evaluator(trava_model=evaluator.trava_model,
-                                       fit_split_data=evaluator.fit_split_data,
-                                       raw_split_data=evaluator.raw_split_data)
+            temp_evaluator = Evaluator(
+                trava_model=evaluator.trava_model,
+                fit_split_data=evaluator.fit_split_data,
+                raw_split_data=evaluator.raw_split_data,
+            )
             scorers_providers: List[ScorersProvider] = list(results_handlers)
             temp_evaluator.evaluate(scorers_providers=scorers_providers)
             temp_evaluators.append(temp_evaluator)
 
-        result = self._results_for_evaluators(evaluators=temp_evaluators,
-                                              results_handlers=results_handlers,
-                                              main_model_id=model_id)
+        result = self._results_for_evaluators(
+            evaluators=temp_evaluators, results_handlers=results_handlers, main_model_id=model_id
+        )
 
         return result
 
-    def evaluate_track(self,
-                       model_id: str,
-                       scorers: List[Scorer]):
+    def evaluate_track(self, model_id: str, scorers: List[Scorer]):
         """
         Similar to evaluate method, but this time it allows you to track new metrics
 
@@ -172,14 +173,10 @@ class TravaSV(_TravaBase):
         for evaluator in evaluators:
             evaluator.evaluate(scorers_providers=[tracker])
 
-            self._track_evaluators(evaluators=[evaluator],
-                                   model_id=evaluator.model_id,
-                                   tracker=tracker)
+            self._track_evaluators(evaluators=[evaluator], model_id=evaluator.model_id, tracker=tracker)
 
         if len(evaluators) > 1:
-            self._track_evaluators(evaluators=evaluators,
-                                   model_id=model_id,
-                                   tracker=tracker)
+            self._track_evaluators(evaluators=evaluators, model_id=model_id, tracker=tracker)
 
     def _tracker_copy(self) -> TravaTracker:
         """
@@ -216,68 +213,71 @@ class TravaSV(_TravaBase):
         maybe_model_results = self._results.get(model_id)
 
         if not maybe_model_results:
-            raise AttributeError('Model with id {} is not found.'.format(model_id))
+            raise AttributeError("Model with id {} is not found.".format(model_id))
 
         return self._results_for_evaluators(evaluators=maybe_model_results.evaluators)
 
-    def _results_for_evaluators(self,
-                                evaluators: List[Evaluator],
-                                save_model_results: bool = False,
-                                results_handlers: Optional[List[ResultsHandler]] = None,
-                                main_model_id: Optional[str] = None) -> list:
+    def _results_for_evaluators(
+        self,
+        evaluators: List[Evaluator],
+        save_model_results: bool = False,
+        results_handlers: Optional[List[ResultsHandler]] = None,
+        main_model_id: Optional[str] = None,
+    ) -> list:
         # if main_model_id is provided it means that all evaluators
         # are related to the one run and must be averaged
-        evaluators_results = self._prepare_model_results(evaluators=evaluators,
-                                                         save=save_model_results,
-                                                         main_model_id=main_model_id)
+        evaluators_results = self._prepare_model_results(
+            evaluators=evaluators, save=save_model_results, main_model_id=main_model_id
+        )
 
         all_results_handlers = results_handlers or self._results_handlers
         return self._results_for(results=evaluators_results, results_handlers=all_results_handlers)
 
-    def _prepare_model_results(self,
-                               evaluators: List[Evaluator],
-                               save: bool = False,
-                               main_model_id: Optional[str] = None) -> List[ModelResult]:
+    def _prepare_model_results(
+        self, evaluators: List[Evaluator], save: bool = False, main_model_id: Optional[str] = None
+    ) -> List[ModelResult]:
         is_agg_result = len(evaluators) > 1 and main_model_id
         evaluators_results = []
         for evaluator in evaluators:
-            model_results = ModelResult(model_id=evaluator.model_id,
-                                        evaluators=[evaluator])
+            model_results = ModelResult(model_id=evaluator.model_id, evaluators=[evaluator])
             evaluators_results.append(model_results)
 
             if not is_agg_result and save:
                 self._results[model_results.model_id] = model_results
         if is_agg_result:
             model_id = str(main_model_id)
-            main_model_result = ModelResult(model_id=model_id,
-                                            evaluators=evaluators)
+            main_model_result = ModelResult(model_id=model_id, evaluators=evaluators)
             evaluators_results = [main_model_result]
             if save:
                 self._results[model_id] = main_model_result
         return evaluators_results
 
-    def _fit_predict(self,
-                     model_id: str,
-                     raw_model,
-                     model_init_params: Optional[dict],
-                     fit_predictor: FitPredictor,
-                     fit_params: dict,
-                     predict_params: dict,
-                     serializer: Optional[ModelSerializer],
-                     split_result: Optional[SplitResult] = None,
-                     description: Optional[str] = None):
+    def _fit_predict(
+        self,
+        model_id: str,
+        raw_model,
+        model_init_params: Optional[dict],
+        fit_predictor: FitPredictor,
+        fit_params: dict,
+        predict_params: dict,
+        serializer: Optional[ModelSerializer],
+        split_result: Optional[SplitResult] = None,
+        description: Optional[str] = None,
+    ):
         all_results_handlers = self._results_handlers + [self._tracker]
         scorers_providers: List[ScorersProvider] = list(all_results_handlers)
 
-        config = FitPredictConfig(raw_split_data=split_result,
-                                  raw_model=raw_model,
-                                  model_init_params=model_init_params,
-                                  model_id=model_id,
-                                  scorers_providers=scorers_providers,
-                                  serializer=serializer,
-                                  fit_params=fit_params,
-                                  predict_params=predict_params,
-                                  description=description)
+        config = FitPredictConfig(
+            raw_split_data=split_result,
+            raw_model=raw_model,
+            model_init_params=model_init_params,
+            model_id=model_id,
+            scorers_providers=scorers_providers,
+            serializer=serializer,
+            fit_params=fit_params,
+            predict_params=predict_params,
+            description=description,
+        )
 
         evaluators = fit_predictor.fit_predict(config=config, tracker=self._tracker)
 
